@@ -12,16 +12,16 @@ class AsyncpgExecutor(BaseExecutor):
     EXPLAIN_PREFIX = "EXPLAIN (FORMAT JSON, VERBOSE)"
     DB_NATIVE = BaseExecutor.DB_NATIVE | {bool, uuid.UUID}
 
-    def Parameter(self, pos: int) -> Parameter:
+    def parameter(self, pos: int) -> Parameter:
         return Parameter("$%d" % (pos + 1,))
 
-    def _prepare_insert_statement(self, columns: List[str], no_generated: bool = False) -> str:
+    def _prepare_insert_statement(self, columns: List[str], has_generated: bool = True) -> str:
         query = (
             self.db.query_class.into(self.model._meta.basetable)
             .columns(*columns)
-            .insert(*[self.Parameter(i) for i in range(len(columns))])
+            .insert(*[self.parameter(i) for i in range(len(columns))])
         )
-        if not no_generated:
+        if has_generated:
             generated_fields = self.model._meta.generated_db_fields
             if generated_fields:
                 query = query.returning(*generated_fields)
